import { useState, useEffect, useRef } from "react";
import { Link, useLocation } from "wouter";

const Header = () => {
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const [isScrolled, setIsScrolled] = useState(false);
  const [location] = useLocation();
  const [logoText, setLogoText] = useState("Present People");
  const [isAnimating, setIsAnimating] = useState(false);
  const [isAlternateText, setIsAlternateText] = useState(false);
  const [isMobileServicesOpen, setIsMobileServicesOpen] = useState(false);
  const [isDropdownOpen, setIsDropdownOpen] = useState(false);
  const dropdownTimeoutRef = useRef<NodeJS.Timeout | null>(null);
  const animationTimeoutRef = useRef<NodeJS.Timeout | null>(null);
  const dropdownRef = useRef<HTMLDivElement>(null);

  const toggleMobileMenu = () => {
    setIsMobileMenuOpen(!isMobileMenuOpen);
  };

  const closeMobileMenu = () => {
    setIsMobileMenuOpen(false);
    setIsMobileServicesOpen(false);
  };

  const toggleMobileServices = () => {
    setIsMobileServicesOpen(!isMobileServicesOpen);
  };

  useEffect(() => {
    const handleScroll = () => {
      if (window.scrollY > 50) {
        setIsScrolled(true);
      } else {
        setIsScrolled(false);
      }
    };

    window.addEventListener("scroll", handleScroll);
    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  }, []);

  const animateLogoText = () => {
    if (isAnimating) return;

    setIsAnimating(true);
    const targetText = "Nice to See You ❤";
    const originalText = "Present People";
    const isReverting = isAlternateText;

    // Pirmiausia išvalome bet kokius ankstesnius timeouts
    if (animationTimeoutRef.current) {
      clearTimeout(animationTimeoutRef.current);
    }

    let eraseIndex = logoText.length;
    let typeIndex = 0;

    // Ištrynimo animacija
    const eraseText = () => {
      if (eraseIndex === 0) {
        // Kai tekstas jau ištrintas, pradedame rašymo animaciją
        animationTimeoutRef.current = setTimeout(typeText, 300); // Trumpa pauzė prieš rašymą
      } else {
        // Ištriname po vieną simbolį
        eraseIndex--;
        setLogoText(logoText.substring(0, eraseIndex));
        animationTimeoutRef.current = setTimeout(eraseText, 50);
      }
    };

    // Rašymo animacija
    const typeText = () => {
      const textToType = isReverting ? originalText : targetText;

      if (typeIndex === textToType.length) {
        // Animacija baigta
        setIsAnimating(false);
        // Nustatome esamą teksto būseną
        setIsAlternateText(!isReverting);
      } else {
        // Pridedame po vieną simbolį
        typeIndex++;
        setLogoText(textToType.substring(0, typeIndex));
        animationTimeoutRef.current = setTimeout(typeText, 150);
      }
    };

    // Pradedame animaciją - pirma ištriname
    eraseText();
  };

  // Valome timeouts, kai komponentas išmontuojamas
  useEffect(() => {
    return () => {
      if (animationTimeoutRef.current) {
        clearTimeout(animationTimeoutRef.current);
      }
      if (dropdownTimeoutRef.current) {
        clearTimeout(dropdownTimeoutRef.current);
      }
    };
  }, []);

  const handleMouseEnter = () => {
    if (dropdownTimeoutRef.current) {
      clearTimeout(dropdownTimeoutRef.current);
    }
    setIsDropdownOpen(true);
  };

  const handleMouseLeave = () => {
    dropdownTimeoutRef.current = setTimeout(() => {
      setIsDropdownOpen(false);
    }, 300); // Maža delsa prieš uždarant meniu, kad būtų laiko pereiti į submeniu
  };

  // Uždarome mobilųjį meniu, kai keičiasi maršrutas
  useEffect(() => {
    closeMobileMenu();
  }, [location]);

  const getNavLinkProps = (href: string) => {
    return {
      href,
      className:
        "uppercase-wide text-xs py-1 hover:text-muted-foreground hover:transition-colors hover:duration-300",
      onClick: closeMobileMenu,
    };
  };

  return (
    <header
      className={`fixed w-full bg-background z-50 ${isScrolled ? "shadow-[0_1px_0_0_rgba(0,0,0,0.1)]" : ""}`}
    >
      <div className="container mx-auto px-6 py-6 flex justify-between items-center">
        {/* Logo - optimizuotas greičiui */}
        <div className="relative">
          <Link
            href="/"
            className="text-lg md:text-xl font-light cursor-pointer"
            aria-label="PRESENTPPL logotipas - grįžti į pagrindinį puslapį"
            onClick={(e) => {
              if (location === "/") {
                e.preventDefault();
                animateLogoText();
              }
            }}
          >
            {/* Optimizuotas staticinis logo su vienodu stiliumi abiem būsenoms */}
            <span
              aria-label={isAnimating ? logoText : (isAlternateText ? "Nice to See You Heart" : "Present People")}
              className={`inline-block font-normal ${isAnimating ? "animate-pulse" : ""}`}
              style={{
                fontFamily: 'system-ui, -apple-system, BlinkMacSystemFont, sans-serif',
                fontSize: 'clamp(1rem, 5vw, 1.25rem)',
                fontWeight: 400,
                fontKerning: 'normal',
                letterSpacing: '-0.01em',
                transition: 'opacity 0.3s ease'
              }}
            >
              {isAnimating ? logoText : (
                isAlternateText ? (
                  <>
                    Nice to See You <span className="text-red-500">❤</span>
                  </>
                ) : "Present People"
              )}
            </span>
            
            <span
              className={`absolute top-0 left-0 right-0 h-0.5 bg-accent transform origin-left ${isAnimating ? "transition-transform duration-300 scale-x-100" : "scale-x-0"}`}
              style={{ willChange: "transform" }}
            ></span>
          </Link>
        </div>

        {/* Desktop Navigation */}
        <nav className="hidden md:flex space-x-8">
          <a {...getNavLinkProps("/#home")}>Pradžia</a>
          <a {...getNavLinkProps("/#about")}>Apie</a>
          <a {...getNavLinkProps("/#portfolio")}>Darbai</a>

          {/* Paslaugos meniu su hover efektu */}
          <div
            className="relative group flex items-center"
            onMouseEnter={handleMouseEnter}
            onMouseLeave={handleMouseLeave}
            ref={dropdownRef}
          >
            <a
              href="/#services"
              className="uppercase-wide text-xs py-1 hover:text-muted-foreground hover:transition-colors hover:duration-300 cursor-pointer bg-transparent border-0"
            >
              Paslaugos
            </a>

            {/* Išskleidžiamas meniu su hover efektu */}
            <div
              className={`absolute z-50 left-1/2 transform -translate-x-1/2 top-full w-64 transition-all duration-300 ${
                isDropdownOpen ? "opacity-100 visible" : "opacity-0 invisible"
              } group-hover:opacity-100 group-hover:visible`}
            >
              {/* Tuščia erdvė virš dropdown, kad išvengtume hover neveikimo */}
              <div className="h-3 w-full"></div>
              <div
                className="bg-background border border-border shadow-lg rounded-md py-2 px-2"
                onMouseEnter={handleMouseEnter}
                onMouseLeave={handleMouseLeave}
              >
                <div className="grid grid-cols-1 gap-2">
                  <Link
                    href="/paslaugos/krikstynos"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md hover:transition-colors hover:duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Krikštynos
                  </Link>
                  <Link
                    href="/paslaugos/vaiku-gimtadieniai"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Vaikų gimtadieniai
                  </Link>
                  <Link
                    href="/paslaugos/reklamines-integracijos"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Reklaminės integracijos
                  </Link>
                  <Link
                    href="/paslaugos/mada"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Mada
                  </Link>
                  <Link
                    href="/paslaugos/atlikeju-pasiruosimas-koncertams"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Atlikėjų koncertai
                  </Link>
                  <Link
                    href="/paslaugos/seimu-fotosesijos"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Šeimų fotosesijos
                  </Link>
                  <Link
                    href="/paslaugos/parodu-atidarymai"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Parodų atidarymai
                  </Link>
                  <Link
                    href="/paslaugos/fotosesiju-backstage"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Fotosesijų backstage
                  </Link>
                  <Link
                    href="/paslaugos/skaitmeninio-turinio-kurimas"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Skaitmeninio turinio kūrimas
                  </Link>
                  <Link
                    href="/paslaugos/vizualine-komunikacija"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Vizualinė komunikacija
                  </Link>
                  <Link
                    href="/paslaugos/renginiu-organizavimo-backstage"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Renginių organizavimo backstage
                  </Link>
                  <Link
                    href="/paslaugos/kaviniu-restoranu-prezentacija"
                    className="px-3 py-1.5 text-xs hover:bg-secondary rounded-md transition-colors duration-200 font-light"
                    onClick={closeMobileMenu}
                  >
                    Kavinių/restoranų prezentacija
                  </Link>
                </div>
              </div>
            </div>
          </div>

          <a {...getNavLinkProps("/#faq")}>DUK</a>
          <a {...getNavLinkProps("/#contact")}>Kontaktai</a>
        </nav>

        {/* Mobile Menu Button */}
        <button
          className="md:hidden focus:outline-none uppercase-wide text-xs"
          onClick={toggleMobileMenu}
          aria-label="Toggle menu"
        >
          {isMobileMenuOpen ? "Uždaryti" : "Meniu"}
        </button>
      </div>

      {/* Mobile Navigation - Full Screen Overlay */}
      <div
        className={`fixed inset-0 bg-background z-40 ${
          isMobileMenuOpen
            ? "opacity-100 transition-opacity duration-300 ease-in-out"
            : "opacity-0 pointer-events-none"
        }`}
        style={{ paddingTop: "80px" }}
        onClick={(e) => {
          // Uždarome meniu tik jei paspaudimas buvo ant pačio overlay (ne ant vaikų elementų)
          if (e.target === e.currentTarget) {
            closeMobileMenu();
          }
        }}
      >
        <div className="container mx-auto px-6 py-8 relative h-full overflow-y-auto">
          {/* Uždarymo mygtukas */}
          <button
            className="absolute top-0 right-6 text-2xl focus:outline-none"
            onClick={closeMobileMenu}
            aria-label="Uždaryti meniu"
          >
            ✕
          </button>

          <nav className="flex flex-col space-y-6 pt-8">
            <a
              onClick={closeMobileMenu}
              href="/#home"
              className="text-2xl uppercase-wide"
            >
              Pradžia
            </a>
            <a
              onClick={closeMobileMenu}
              href="/#about"
              className="text-2xl uppercase-wide"
            >
              Apie
            </a>
            <a
              onClick={closeMobileMenu}
              href="/#portfolio"
              className="text-2xl uppercase-wide"
            >
              Darbai
            </a>

            {/* Paslaugų submeniu mobiliame */}
            <div className="flex flex-col space-y-4">
              <div className="flex justify-between items-center">
                <a
                  href="/#services"
                  onClick={() => {
                    closeMobileMenu();
                  }}
                  className="text-2xl uppercase-wide"
                >
                  Paslaugos
                </a>
                <button
                  className="focus:outline-none p-2"
                  onClick={toggleMobileServices}
                  aria-expanded={isMobileServicesOpen}
                >
                  <span
                    className={`transform ${isMobileServicesOpen ? "rotate-180 transition-transform duration-200" : ""}`}
                  >
                    ▼
                  </span>
                </button>
              </div>

              {isMobileServicesOpen && (
                <div className="pl-4 flex flex-col space-y-3">
                  <Link
                    href="/paslaugos/krikstynos"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Krikštynos
                  </Link>
                  <Link
                    href="/paslaugos/vaiku-gimtadieniai"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Vaikų gimtadieniai
                  </Link>
                  <Link
                    href="/paslaugos/reklamines-integracijos"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Reklaminės integracijos
                  </Link>
                  <Link
                    href="/paslaugos/mada"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Mada
                  </Link>
                  <Link
                    href="/paslaugos/atlikeju-pasiruosimas-koncertams"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Atlikėjų koncertai
                  </Link>
                  <Link
                    href="/paslaugos/seimu-fotosesijos"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Šeimų fotosesijos
                  </Link>
                  <Link
                    href="/paslaugos/parodu-atidarymai"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Parodų atidarymai
                  </Link>
                  <Link
                    href="/paslaugos/fotosesiju-backstage"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Fotosesijų backstage
                  </Link>
                  <Link
                    href="/paslaugos/skaitmeninio-turinio-kurimas"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Skaitmeninio turinio kūrimas
                  </Link>
                  <Link
                    href="/paslaugos/vizualine-komunikacija"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Vizualinė komunikacija
                  </Link>
                  <Link
                    href="/paslaugos/renginiu-organizavimo-backstage"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Renginių organizavimo backstage
                  </Link>
                  <Link
                    href="/paslaugos/kaviniu-restoranu-prezentacija"
                    className="text-lg"
                    onClick={closeMobileMenu}
                  >
                    Kavinių/restoranų prezentacija
                  </Link>
                </div>
              )}
            </div>

            <a
              onClick={closeMobileMenu}
              href="/#faq"
              className="text-2xl uppercase-wide"
            >
              DUK
            </a>
            <a
              onClick={closeMobileMenu}
              href="/#contact"
              className="text-2xl uppercase-wide"
            >
              Kontaktai
            </a>
          </nav>

          {/* Papildomas uždarymo mygtukas apačioje */}
          <button
            className="mt-8 border border-border w-full py-4 uppercase-wide"
            onClick={closeMobileMenu}
          >
            Uždaryti meniu
          </button>
        </div>
      </div>
    </header>
  );
};

export default Header;
